==> deepin-screenshot_4.1.1.orig.tar.gz: deepin-screenshot-4.1.1/CHANGELOG.md <==
<a name="4.1.0"></a>
## 4.1.1 (2018-08-31)


#### Features

*   use deepin-turbo ([a6d6528f](a6d6528f))

<a name="4.0.16"></a>
## 4.0.16 (2018-06-12)

#### Bug Fixes

*   not save img for cmdline ([e284f743](e284f743))
* **flatpak:**  cannot open help manual in flatpak ([7abae000](7abae000))
*   Update version.


<a name="4.0.15"></a>
### 4.0.15 (2018-06-07)


#### Bug Fixes

*   not save screenshot from cmdline path ([85b51d63](85b51d63))

<a name="4.0.14"></a>
## 4.0.14 (2018-05-31)


#### Bug Fixes

*   magnifier update not timely ([f0846718](f0846718))
*   manual can't open on flatpak envs ([47111401](47111401))



<a name="4.0.13"></a>
## 4.0.13 (2018-05-30)


#### Bug Fixes

*   restore blur and mosaic ([8cc26005](8cc26005))



<a name="4.0.12"></a>
## 4.0.12 (2018-05-30)


#### Bug Fixes

*   flatpak error readding config file. ([320648ec](320648ec))
*   not draw faker background ([0f7f3f71](0f7f3f71))
*   draw background error ([0cd42039](0cd42039))



<a name="4.0.12"></a>
## 4.0.12 (2018-05-29)


#### Bug Fixes

*   flatpak error readding config file. ([320648ec](320648ec))
*   not draw faker background ([0f7f3f71](0f7f3f71))
*   draw background error ([0cd42039](0cd42039))



<a name="4.0.11"></a>
## 4.0.11 (2018-03-07)


#### Bug Fixes

*   top level window shortcut misplaced ([83e8b94c](83e8b94c))
*   Adapt lintian ([51eef7f5](51eef7f5))
*   correct a typo in screenshot.cpp ([14f4b936](14f4b936))
*   check controlcenter and hotzone dbus is valid ([32625d1a](32625d1a))
* **hidpi:**  window background misplaced ([a3e50aa5](a3e50aa5))

#### Features

*   add manual id ([15cd1c85](15cd1c85))
*   add dbus service ([d1bdd2a4](d1bdd2a4))
* **hidpi:**  basic hidpi support ([575a326e](575a326e))

==> deepin-screenshot_4.1.2.orig.tar.gz: deepin-screenshot-4.1.2/CHANGELOG.md <==
<a name="4.1.2"></a>
## 4.1.2 (2018-10-25)


#### Features

*   use deepin-turbo ([a6d6528f](a6d6528f))
*   add manual id ([15cd1c85](15cd1c85))
*   add dbus service ([d1bdd2a4](d1bdd2a4))
* **hidpi:**  basic hidpi support ([575a326e](575a326e))

#### Bug Fixes

*   qm file install location is incorrect. ([d50c45f0](d50c45f0))
*   not save img for cmdline ([e284f743](e284f743))
*   not save screenshot from cmdline path ([85b51d63](85b51d63))
*   magnifier update not timely ([f0846718](f0846718))
*   manual can't open on flatpak envs ([47111401](47111401))
*   restore blur and mosaic ([8cc26005](8cc26005))
*   save the correct pixmap. ([fab1a62a](fab1a62a))
*   flatpak error readding config file. ([320648ec](320648ec))
*   not draw faker background ([0f7f3f71](0f7f3f71))
*   draw background error ([0cd42039](0cd42039))
*   top level window shortcut misplaced ([83e8b94c](83e8b94c))
*   Adapt lintian ([51eef7f5](51eef7f5))
*   correct a typo in screenshot.cpp ([14f4b936](14f4b936))
*   check controlcenter and hotzone dbus is valid ([32625d1a](32625d1a))
* **flatpak:**  cannot open help manual in flatpak ([7abae000](7abae000))
* **hidpi:**  window background misplaced ([a3e50aa5](a3e50aa5))



<a name="4.1.0"></a>
## 4.1.1 (2018-08-31)


#### Features

*   use deepin-turbo ([a6d6528f](a6d6528f))

<a name="4.0.16"></a>
## 4.0.16 (2018-06-12)

#### Bug Fixes

*   not save img for cmdline ([e284f743](e284f743))
* **flatpak:**  cannot open help manual in flatpak ([7abae000](7abae000))
*   Update version.


<a name="4.0.15"></a>
### 4.0.15 (2018-06-07)


#### Bug Fixes

*   not save screenshot from cmdline path ([85b51d63](85b51d63))

<a name="4.0.14"></a>
## 4.0.14 (2018-05-31)


#### Bug Fixes

*   magnifier update not timely ([f0846718](f0846718))
*   manual can't open on flatpak envs ([47111401](47111401))



<a name="4.0.13"></a>
## 4.0.13 (2018-05-30)


#### Bug Fixes

*   restore blur and mosaic ([8cc26005](8cc26005))



<a name="4.0.12"></a>
## 4.0.12 (2018-05-30)


#### Bug Fixes

*   flatpak error readding config file. ([320648ec](320648ec))
*   not draw faker background ([0f7f3f71](0f7f3f71))
*   draw background error ([0cd42039](0cd42039))



<a name="4.0.12"></a>
## 4.0.12 (2018-05-29)


#### Bug Fixes

*   flatpak error readding config file. ([320648ec](320648ec))
*   not draw faker background ([0f7f3f71](0f7f3f71))
*   draw background error ([0cd42039](0cd42039))



<a name="4.0.11"></a>
## 4.0.11 (2018-03-07)


#### Bug Fixes

*   top level window shortcut misplaced ([83e8b94c](83e8b94c))
*   Adapt lintian ([51eef7f5](51eef7f5))
*   correct a typo in screenshot.cpp ([14f4b936](14f4b936))
*   check controlcenter and hotzone dbus is valid ([32625d1a](32625d1a))
* **hidpi:**  window background misplaced ([a3e50aa5](a3e50aa5))

#### Features

*   add manual id ([15cd1c85](15cd1c85))
*   add dbus service ([d1bdd2a4](d1bdd2a4))
* **hidpi:**  basic hidpi support ([575a326e](575a326e))
